@@ -1,7 +1,7 @@
 package IO::Stringy;
 
 use vars qw($VERSION);
-$VERSION = substr q$Revision: 1.212 $, 10;
+$VERSION = substr q$Revision: 1.213 $, 10;
 
 1;
 __END__
@@ -27,18 +27,20 @@ IO-stringy - I/O on in-core objects like strings and arrays
 
 This toolkit primarily provides modules for performing both traditional 
 and object-oriented i/o) on things I<other> than normal filehandles; 
-in particular, L<IO::Scalar>, L<IO::ScalarArray>, and L<IO::Lines>.
+in particular, L<IO::Scalar|IO::Scalar>, L<IO::ScalarArray|IO::ScalarArray>, 
+and L<IO::Lines|IO::Lines>.
 
 If you have access to tie(), these classes will make use of the
-L<IO::WrapTie> module to inherit a convenient new_tie() constructor.
-It also exports a nice wraptie() function.
+L<IO::WrapTie|IO::WrapTie> module to inherit a convenient new_tie() 
+constructor.  It also exports a nice wraptie() function.
 
-In the more-traditional IO::Handle front, we have L<IO::AtomicFile>
+In the more-traditional IO::Handle front, we 
+have L<IO::AtomicFile|IO::AtomicFile>
 which may be used to painlessly create files which are updated
 atomically.
 
-And in the "this-may-prove-useful" corner, we have L<IO::Wrap>, whose
-exported wraphandle() function will clothe anything that's not
+And in the "this-may-prove-useful" corner, we have L<IO::Wrap|IO::Wrap>, 
+whose exported wraphandle() function will clothe anything that's not
 a blessed object in an IO::Handle-like wrapper... so you can just
 use OO syntax and stop worrying about whether your function's caller
 handed you a string, a globref, or a FileHandle.
@@ -53,62 +55,74 @@ You know the drill...
     make install
 
 
+
+=head1 VERSION
+
+$Id: Stringy.pm,v 1.213 2000/08/16 04:59:02 eryq Exp $
+
+
+
 =head1 CHANGE LOG 
 
 =over 4
 
 
-=item Version 1.212
+=item Version 1.213   (2000/08/16)
+
+Minor documentation fixes.
+
+
+=item Version 1.212   (2000/06/02)
 
 Fixed IO::InnerFile incompatibility with Perl5.004.
 I<Thanks to many folks for reporting this.>
 
 
-=item Version 1.210
+=item Version 1.210   (2000/04/17)
 
 Added flush() and other no-op methods.
 I<Thanks to Doru Petrescu for suggesting this.>
 
 
-=item Version 1.209
+=item Version 1.209   (2000/03/17)
 
 Small bug fixes.
 
 
-=item Version 1.208
+=item Version 1.208   (2000/03/14)
 
 Incorporated a number of contributed patches and extensions,
 mostly related to speed hacks, support for "offset", and
 WRITE/CLOSE methods.
 
 
-=item Version 1.206
+=item Version 1.206   (1999/04/18)
 
 Added creation of ./testout when Makefile.PL is run.
 
 
-=item Version 1.205
+=item Version 1.205   (1999/01/15)
 
 Verified for Perl5.005.
 
 
-=item Version 1.202
+=item Version 1.202   (1998/04/18)
 
 New IO::WrapTie and IO::AtomicFile added.
 
 
-=item Version 1.110
+=item Version 1.110   
 
 Added IO::WrapTie.
 
 
-=item Version 1.107
+=item Version 1.107   
 
 Added IO::Lines, and made some bug fixes to IO::ScalarArray. 
 Also, added getc().
 
 
-=item Version 1.105
+=item Version 1.105   
 
 No real changes; just upgraded IO::Wrap to have a $VERSION string.
 
@@ -117,13 +131,6 @@ No real changes; just upgraded IO::Wrap to have a $VERSION string.
 
 
 
-=head1 VERSION
-
-$Id: Stringy.pm,v 1.212 2000/06/02 06:30:15 eryq Exp $
-
-
-
-
 =head1 AUTHOR
 
 Eryq (F<eryq@zeegee.com>).
